@@ -1,7 +1,9 @@
 use std::ops::Deref;
 use std::path::{Path, PathBuf};
+use std::time::Duration;
 
 use uv_dirs::{system_config_file, user_config_dir};
+use uv_flags::EnvironmentFlags;
 use uv_fs::Simplified;
 use uv_static::EnvVars;
 use uv_warnings::warn_user;
@@ -551,7 +553,8 @@ pub enum Error {
     #[error("Failed to parse: `{}`", _0.user_display())]
     UvToml(PathBuf, #[source] Box<toml::de::Error>),
 
-    #[error("Failed to parse: `{}`. The `{}` field is not allowed in a `uv.toml` file. `{}` is only applicable in the context of a project, and should be placed in a `pyproject.toml` file instead.", _0.user_display(), _1, _1)]
+    #[error("Failed to parse: `{}`. The `{}` field is not allowed in a `uv.toml` file. `{}` is only applicable in the context of a project, and should be placed in a `pyproject.toml` file instead.", _0.user_display(), _1, _1
+    )]
     PyprojectOnlyField(PathBuf, &'static str),
 
     #[error("Failed to parse environment variable `{name}` with invalid value `{value}`: {err}")]
@@ -568,18 +571,60 @@ pub enum Error {
 /// the CLI level, however there are limited semantics in that context.
 #[derive(Debug, Clone)]
 pub struct EnvironmentOptions {
+    pub skip_wheel_filename_check: Option<bool>,
     pub python_install_bin: Option<bool>,
     pub python_install_registry: Option<bool>,
+    pub install_mirrors: PythonInstallMirrors,
+    pub log_context: Option<bool>,
+    pub http_timeout: Duration,
+    pub upload_http_timeout: Duration,
+    #[cfg(feature = "tracing-durations-export")]
+    pub tracing_durations_file: Option<PathBuf>,
 }
 
 impl EnvironmentOptions {
     /// Create a new [`EnvironmentOptions`] from environment variables.
     pub fn new() -> Result<Self, Error> {
+        // Timeout options, matching https://doc.rust-lang.org/nightly/cargo/reference/config.html#httptimeout
+        // `UV_REQUEST_TIMEOUT` is provided for backwards compatibility with v0.1.6
+        let http_timeout = parse_integer_environment_variable(EnvVars::UV_HTTP_TIMEOUT)?
+            .or(parse_integer_environment_variable(
+                EnvVars::UV_REQUEST_TIMEOUT,
+            )?)
+            .or(parse_integer_environment_variable(EnvVars::HTTP_TIMEOUT)?)
+            .map(Duration::from_secs);
+
         Ok(Self {
+            skip_wheel_filename_check: parse_boolish_environment_variable(
+                EnvVars::UV_SKIP_WHEEL_FILENAME_CHECK,
+            )?,
             python_install_bin: parse_boolish_environment_variable(EnvVars::UV_PYTHON_INSTALL_BIN)?,
             python_install_registry: parse_boolish_environment_variable(
                 EnvVars::UV_PYTHON_INSTALL_REGISTRY,
             )?,
+            install_mirrors: PythonInstallMirrors {
+                python_install_mirror: parse_string_environment_variable(
+                    EnvVars::UV_PYTHON_INSTALL_MIRROR,
+                )?,
+                pypy_install_mirror: parse_string_environment_variable(
+                    EnvVars::UV_PYPY_INSTALL_MIRROR,
+                )?,
+                python_downloads_json_url: parse_string_environment_variable(
+                    EnvVars::UV_PYTHON_DOWNLOADS_JSON_URL,
+                )?,
+            },
+            log_context: parse_boolish_environment_variable(EnvVars::UV_LOG_CONTEXT)?,
+            upload_http_timeout: parse_integer_environment_variable(
+                EnvVars::UV_UPLOAD_HTTP_TIMEOUT,
+            )?
+            .map(Duration::from_secs)
+            .or(http_timeout)
+            .unwrap_or(Duration::from_secs(15 * 60)),
+            http_timeout: http_timeout.unwrap_or(Duration::from_secs(30)),
+            #[cfg(feature = "tracing-durations-export")]
+            tracing_durations_file: parse_path_environment_variable(
+                EnvVars::TRACING_DURATIONS_FILE,
+            ),
         })
     }
 }
@@ -635,3 +680,75 @@ fn parse_boolish_environment_variable(name: &'static str) -> Result<Option<bool>
 
     Ok(Some(value))
 }
+
+/// Parse a string environment variable.
+fn parse_string_environment_variable(name: &'static str) -> Result<Option<String>, Error> {
+    match std::env::var(name) {
+        Ok(v) => {
+            if v.is_empty() {
+                Ok(None)
+            } else {
+                Ok(Some(v))
+            }
+        }
+        Err(e) => match e {
+            std::env::VarError::NotPresent => Ok(None),
+            std::env::VarError::NotUnicode(err) => Err(Error::InvalidEnvironmentVariable {
+                name: name.to_string(),
+                value: err.to_string_lossy().to_string(),
+                err: "expected a valid UTF-8 string".to_string(),
+            }),
+        },
+    }
+}
+
+/// Parse a integer environment variable.
+fn parse_integer_environment_variable(name: &'static str) -> Result<Option<u64>, Error> {
+    let value = match std::env::var(name) {
+        Ok(v) => v,
+        Err(e) => {
+            return match e {
+                std::env::VarError::NotPresent => Ok(None),
+                std::env::VarError::NotUnicode(err) => Err(Error::InvalidEnvironmentVariable {
+                    name: name.to_string(),
+                    value: err.to_string_lossy().to_string(),
+                    err: "expected an integer".to_string(),
+                }),
+            };
+        }
+    };
+    if value.is_empty() {
+        return Ok(None);
+    }
+    match value.parse::<u64>() {
+        Ok(v) => Ok(Some(v)),
+        Err(_) => Err(Error::InvalidEnvironmentVariable {
+            name: name.to_string(),
+            value,
+            err: "expected an integer".to_string(),
+        }),
+    }
+}
+
+#[cfg(feature = "tracing-durations-export")]
+/// Parse a path environment variable.
+fn parse_path_environment_variable(name: &'static str) -> Option<PathBuf> {
+    let value = std::env::var_os(name)?;
+
+    if value.is_empty() {
+        return None;
+    }
+
+    Some(PathBuf::from(value))
+}
+
+/// Populate the [`EnvironmentFlags`] from the given [`EnvironmentOptions`].
+impl From<&EnvironmentOptions> for EnvironmentFlags {
+    fn from(options: &EnvironmentOptions) -> Self {
+        let mut flags = Self::empty();
+        if options.skip_wheel_filename_check == Some(true) {
+            flags.insert(Self::SKIP_WHEEL_FILENAME_CHECK);
+        }
+        flags
+    }
+}
